/**
 * @function pre_action
 * @description 加减商品数量预处理函数
 *              加减商品数量后不会立刻请求服务器获取价格
 *              而是等待200ms后再执行，如果期间内
 *              又发生了加减商品数量
 *              重复等待200ms
 */
function pre_action() {
    if (change_price_timeout != null) {
        clearTimeout(change_price_timeout)
    }
    change_price_timeout = setTimeout(function() {
        change_price()
    }, 200)
}

/**
 * @function change_price
 * @description 点选可选属性或改变数量时修改商品价格的函数
 */
function change_price() {
    var attr = get_select_attr()
    var qty = $('#number').val()
    ajax({
        data : {
            script_name : 'goods',
            act : 'price',
            id : page_param['id'],
            cvs_id : page_param['cvs_id'],
            attr : attr,
            number : qty,
        },
        success : cb_change_price,
        type : 'GET',
    })
}

/**
 * @function cb_change_price
 * @description 接收返回的信息
 * @param {string} data 服务器端返回的数据
 */
function cb_change_price(data) {
    var json = parse_result(data)
    json.attr_num = json.attr_num || 0
    json.qty = json.qty || 0
    if (json.err_msg.length > 0) {
        open_toast(json.err_msg)
    } else {
        $('#number').val(json.qty)
        $('.goods_price_label').html(json.result)
        $('#goods_number').html(json.attr_num)
        if (parseInt(json.attr_num) > 0) {
            $('#has_stock_label').html('有货')
            $('.buy_now').addClass('bc-head1')
            $('.buy_now').removeClass('bc-grey5')
        } else {
            $('#has_stock_label').html('无货');
            $('.buy_now').removeClass('bc-head1')
            $('.buy_now').addClass('bc-grey5')
        }
    }
}

/**
 * @function get_select_attr
 * @description 获得选定的商品属性
 */
function get_select_attr() {
    var spec_arr = new Array()
    var j = 0;
    $('.goods_attr').each(function() {
        if ($(this).hasClass('selected') && !$(this).hasClass('disabled')) {
            spec_arr[j] = $(this).attr('attr_id')
            j++
        }
    })
    return spec_arr
}

/**
 * @function select_attr
 * @description 选择商品属性事件
 * @param {string} attr_id 属性ID
 * @param {string} spec_key 属性类别
 */
function select_attr(attr_id, spec_key) {
    var target = $('.goods_attr').not(function() {
        return !($(this).attr('attr_id') == attr_id && $(this).attr('spec_key') == spec_key)
    })
    if ($(target).hasClass('disabled')) {
        return false
    }
    $(target).toggleClass('selected')
    if ($(target).hasClass('selected')) {
        selected_attr = new Array()
        show_attr_status(attr_id, spec_key)
        change_price()
    } else {
        unselect_all_status()
        change_price()
    }
}

/**
 * @function unselect_all_status
 * @description 取消所有属性选择状态
 */
function unselect_all_status() {
    $('.spec_key').find('.goods_attr').removeClass('selected').removeClass('disabled')
}

/**
 * @function show_attr_status
 * @description 判断所有属性选择状态
 * @param {string} attr_id 当前要判断选中状态的属性
 * @param {string} spec_key 属性类别
 */
function show_attr_status(attr_id, spec_key) {
    selected_attr.push(attr_id)

    $('.spec_key').each(function() {
        var first_attr_id

        //判断同一类别的属性的状态
        if ($(this).attr('spec_key') == spec_key) {
            $(this).find('.goods_attr').each(function() {
                //所有其他属性取消选择状态
                if ($(this).attr('attr_id') != attr_id) {
                    $(this).removeClass('selected')
                }
            })
        }
        //操作其它类别下的属性状态
        else {
            //是否有选择状态的属性
            $(this).find('.goods_attr').each(function() {
                var target_attr_id = $(this).attr('attr_id')
                var is_target_selected = $(this).hasClass('selected')
                if (is_exist_prod(selected_attr, target_attr_id)) {
                    if (is_target_selected) {
                        first_attr_id = target_attr_id
                    } else {
                        if ( typeof first_attr_id == 'undefined') {
                            first_attr_id = target_attr_id
                        }
                    }
                    $(this).removeClass('disabled')
                } else {
                    $(this).removeClass('selected')
                    $(this).addClass('disabled')
                }
            })
            if ( typeof first_attr_id != 'undefined') {
                selected_attr.push(first_attr_id)
                $('#spec_key_' + $(this).attr('spec_key') + '_attr_id_' + first_attr_id).addClass('selected');
            }
        }
    })
}

/***
 * @function is_exist_prod
 * @description 是否存在此货品
 *              目标属性和已经选择的属性同时存在一个货品
 * @param {string} selected_attr 已经选择的属性
 * @param {string} target 目标属性
 * @returns {boolean} exist 是否存在
 */
function is_exist_prod(selected_attr, target) {
    if (prod_exist_arr.length == 0) {
        return false
    }
    var exist = true
    for (var j in prod_exist_arr) {
        var prod = prod_exist_arr[j]
        var tmp = (prod.indexOf("|" + target + "|") != -1)
        for (i in selected_attr) {
            tmp = tmp && (prod.indexOf("|" + selected_attr[i] + "|") != -1)
        }
        if (tmp) {
            break
        }
    }
    exist = exist && tmp
    return exist
}

/**
 * @function
 * @description 获取属性对应的图片
 * @param {string} attr_id 属性ID
 */
function get_gallery_attr(attr_id) {
    ajax({
        data : {
            script_name : 'goods',
            act : 'get_gallery_attr',
            id : page_param['id'],
            cvs_id : page_param['cvs_id'],
            goods_attr_id : attr_id,
        },
        success : cb_get_gallery_attr,
        type : 'GET',
    })
}

/**
 * @function cb_get_gallery_attr
 * @description 获取属性图片回调函数
 * @param {string} data 服务器端返回的数据
 * @returns {boolean} false
 */
function cb_get_gallery_attr(data) {
    var json = JSON.parse(data)
    var slides = json.content
    goods_attr_swiper.removeAllSlides()
    goods_attr_swiper.appendSlide(slides)
    return false
}

/**
 * @function collect
 * @description 收藏商品
 */
function collect() {
    ajax({
        data : {
            script_name : 'user',
            act : 'collect',
            id : page_param['id'],
        },
        success : cb_collect,
        type : 'GET',
    })
}

/**
 * @function cb_collect
 * @description 收藏商品回调函数
 * @param {string} data 服务器端返回的数据
 */
function cb_collect(data) {
    var json = parse_result(data)
    if (json) {
        if (json.error <= 0) {
            $('#collect_button').attr('is_collect', 1)
            $('#collect_button').attr('collect_id', json.collect_id)
            $('#collect_button').find('div').first().toggleClass('shoucang-off shoucang-on')
            $('#collect_button').find('div').last().html('已收藏')
            open_toast(json.message)
            publish(CHANNEL_COLLECT_GOODS)
        }
    }
}

/**
 * @function uncollect
 * @description 取消收藏商品
 */
function uncollect(rec_id) {
    ajax({
        data : {
            script_name : 'user',
            act : 'delete_collection',
            collection_id : rec_id,
        },
        success : cb_uncollect,
        type : 'GET',
    })
}

/**
 * @function cb_uncollect
 * @description 取消收藏商品回调函数
 * @param {string} data 服务器端返回的数据
 */
function cb_uncollect(data) {
    var json = parse_result(data)
    if (json) {
        if (json.error <= 0) {
            $('#collect_button').attr('is_collect', 0)
            $('#collect_button').attr('collect_id', '')
            $('#collect_button').find('div').first().toggleClass('shoucang-off shoucang-on')
            $('#collect_button').find('div').last().html('收藏')
            open_toast(json.content)
            publish(CHANNEL_UNCOLLECT_GOODS)
        }
    }
}

/**
 * @function get_more_comment
 * @description 获取更多评论
 */
function get_more_comment() {
    comment_page++
    get_comments()
}

/**
 * @function get_comments
 * @description 获取更多评论
 */
function get_comments() {
    $.scroll.running = true
    ajax({
        data : {
            script_name : 'goods_comment',
            act : 'list_json',
            goods_id : page_param['id'],
            type : comment_type,
            page : comment_page,
        },
        success : cb_get_comments,
        type : 'GET',
    })
}

/**
 * @function cb_get_comments
 * @description 获取更多评论 回调函数
 * @param {string} data 服务器端返回的数据
 */
function cb_get_comments(data) {
    var json = parse_result(data)
    if (json) {
        if (json.error == ERR_END_OF_LIST) {
            $('#' + $.scroll.get('indicator_id')).addClass('disabled')
            $('#' + $.scroll.get('indicator_id')).html('没有更多内容')
            $.scroll.set({
                disabled : true
            })
        } else {
            if (comment_page == 1) {
                $('#comment_container').html(json.content)
            } else {
                $('#comment_container').append(json.content)
            }
            init_good_num()
            init_empty_image()
            init_shaidan_img()
            $.scroll.running = false
        }
    }
}

/**
 * @function init_shaidan_img
 * @description 初始化晒单图片
 */
function init_shaidan_img() {
    $('.shaidan_img').each(function(index) {
        var target = this
        var active_index = index
        $(target).find('img').on('click', function() {
            var image_src = $(this).attr('origin')
            var image_arr = new Array()
            $(target).siblings().each(function() {
                image_arr.push($(this).find('img').attr('origin'))
            })
            image_arr.splice(active_index, 0, image_src)
            uexImageBrowser.open(image_arr, active_index)
        })
    })
}

/**
 * @function init_good_num
 * @description 初始化有用按钮
 */
function init_good_num() {
    $('.good_num').on('click', function() {
        show_good($(this).attr('comment_id'))
    })
}

/**
 * @function show_good
 * @description 点击有用
 * @param {string} comment_id 评论ID
 */
function show_good(comment_id) {
    ajax({
        data : {
            script_name : 'goods_comment',
            act : 'good_json',
            comment_id : comment_id,
        },
        success : cb_show_good,
        type : 'GET',
    })
}

/**
 * @function cb_show_good
 * @description 点击有用 回调函数
 * @param {string} data 服务器端返回的数据
 */
function cb_show_good(data) {
    result = JSON.parse(data);
    if (result.error == 1) {
        open_alert("您已经评过分了！")
    } else {
        $('#good_num_' + result.comment_id).html(result.good_num);
    }
}

/**
 * @function cb_show_good
 * @description 获取更多商品 回调函数
 * @param {string} data 服务器端返回的数据
 */
function cb_get_goods(data) {
    var json = parse_result(data)
    if (json) {
        var content = json.content
        if (page_param['page'] == 1) {
            $('#goods_list_container').html(content)
        } else {
            $('#goods_list_container').before(content)
        }
        init_goods()
    }
}

/**
 * @function confirm_add_to_cart
 * @description 加入购物车
 */
function confirm_add_to_cart() {
    if ($('.spec_key').length > 0 && get_select_attr().length < $('.spec_key').length) {
        open_alert('请选择商品属性')
        return false
    }
    add_to_cart(page_param['id'],$('#buy_number').val(),$('#goods_status').val(),get_select_attr(), 0, 0, one_step_buy)
    close_popup()
}

/**
 * @function open_pop_menu
 * @description 打开弹窗
 */
function open_pop_menu() {
    $('#pop_menu1').toggleClass('uhide');
    $('#cover_div').toggleClass('uhide');
}

/**
 * @function init_menu_tab
 * @description 初始化标签切换
 */
function init_menu_tab() {
    $('.menu._checkbox').on('click', function() {
        var value = $(this).attr('value')
        if ($(this).prop('checked')) {
            $('#menu_content').children().addClass('uhide')
            $('#' + value).removeClass('uhide')
            $('#menu_background').removeClass('uhide')
            $('#menu_content').removeClass('uhide')
            if ( typeof $.bounce != 'undefined') {
                $.bounce.disable()
            }
        } else {
            $('#menu_content').addClass('uhide')
            if ( typeof $.bounce != 'undefined') {
                $.bounce.enable()
            }
        }
    })
    $('#menu_background').on('click', function() {
        $(get_checkbox_target({name:'menu_list'})[0]).trigger('click')
    })
}

/**
 * @function init_region_select
 * @description 初始化区域选择
 */
function init_region_select() {
    $('.xiangcun').on('click', function() {
        var xiangcun_id = $(this).attr('value')
        var district_id = $(this).attr('name')
        district_id = district_id.replace('region_', '')

        var region_label = $('#tab_' + district_id).children().first().html()
        if ( typeof region_label == 'undefined' || region_label == '') {
            region_label = '当前地区'
        }
        if (xiangcun_id > '0') {
            region_label = $(this).children().first().html()
        }
        $('#region_label').html(region_label)

        set_region({
            district : {
                id : district_id
            },
            xiangcun : {
                id : xiangcun_id
            }
        })
        page_param['distance'] = '0'

        $('#region_list_button').trigger('click')
        $.sort.get('resort')()
    })

    $('#tab_all_city').on('click', function() {
        set_region({
            district : {
                id : 0,
                name : '未知'
            },
            xiangcun : {
                id : 0,
                name : '未知'
            }
        })
        $('#region_label').html('全城')
        page_param['distance'] = '0'
        $('#region_list_button').trigger('click')
        $.sort.get('resort')()
    })

    $('.distance').on('click', function() {
        page_param['distance'] = $(this).attr('value')
        $('#region_label').html('附近&nbsp;' + page_param['distance'] + 'km')
        $('#region_list_button').trigger('click')
        $.sort.get('resort')()
    })
}

/**
 * @function init_nearby
 * @description 初始化附近选项
 *              首先判断是否需要重新定位
 *              如果需要，则定位后在判断是否显示附近
 *              否则直接判断是否显示附近
 */
function init_nearby() {
    if (is_need_reloc()) {
        subscribe(CHANNEL_GET_ADDRESS, function() {
            show_nearby_area()
        })
        get_address()
    } else {
        show_nearby_area()
    }
}

/**
 * @function show_nearby_area
 * @description 判断是否显示附近选项
 *              如果在实际所在城市和所选城市相同
 *              则在区域选择中显示附近选项
 */
function show_nearby_area() {
    var location = get_location()
    var region = get_region()
    if (location.city.id == region.city.id) {
        page_param['lat'] = location.lat
        page_param['log'] = location.log
        $('.nearby_area').removeClass('uhide')
    } else {
        $('.nearby_area').addClass('uhide')
    }
}
